@@ -3,7 +3,7 @@ import os
 
 from . import _check_int, _check_str
 
-__all__ = ["glob_resolver", "glob_scanner", "glob_filter"]
+__all__ = ["glob_scanner", "glob_filter", "glob_scanners", "glob_filters"]
 
 _ESCAPE_SQUARE = glob.escape("[")
 
@@ -13,9 +13,8 @@ def _glob0(pathname, recursive=False):
 
 
 def _glob1(pathname, recursive=False):
-    pathname = os.fspath(pathname)
     # Escape all square brackets to prevent glob from resolving them.
-    pathname = pathname.replace("[", _ESCAPE_SQUARE)
+    pathname = os.fspath(pathname).replace("[", _ESCAPE_SQUARE)
     yield from glob.iglob(pathname, recursive=recursive)
 
 
@@ -23,7 +22,7 @@ def _glob2(pathname, recursive=False):
     yield from glob.iglob(pathname, recursive=recursive)
 
 
-def _get_glob_func(mode):
+def _get_glob(mode):
     _check_int(mode, "mode")
     if mode == 0:
         return _glob0
@@ -35,7 +34,29 @@ def _get_glob_func(mode):
         raise ValueError(f"mode must be in {{0, 1, 2}}, got {mode}")
 
 
-def glob_resolver(pathname, *, mode=1, recursive=False):
+def _path_filter(pathnames, *, type="a"):
+    _check_str(type, "type")
+    type = type.lower()
+    if type not in {"a", "d", "f"}:
+        raise ValueError(f"type must be in {{'a', 'd', 'f'}}, got '{type}'")
+
+    all_ok = type == "a"
+    dir_ok = all_ok or type == "d"
+    file_ok = all_ok or type == "f"
+
+    for path in pathnames:
+        if os.path.isdir(path):
+            if dir_ok:
+                yield path
+        elif os.path.isfile(path):
+            if file_ok:
+                yield path
+        else:
+            if all_ok:
+                yield path
+
+
+def glob_scanner(pathname, *, mode=1, recursive=False):
     """Resolve a pathname with glob patterns.
 
     Parameters
@@ -55,11 +76,38 @@ def glob_resolver(pathname, *, mode=1, recursive=False):
         The glob matched pathname.
     """
 
-    glob_func = _get_glob_func(mode)
-    yield from glob_func(pathname, recursive=recursive)
+    glob = _get_glob(mode)
+    yield from glob(pathname, recursive=recursive)
 
 
-def glob_scanner(pathnames, *, mode=1, recursive=False):
+def glob_filter(pathname, *, mode=1, recursive=False, type="a"):
+    """Resolve and filter a pathname with glob patterns.
+
+    Parameters
+    ----------
+    pathname : str or path-like
+        A pathname with glob patterns.
+    mode : int, default=1
+        The mode of glob. If ``0``, disable glob pathname pattern; if ``1``,
+        resolve ``*`` and ``?``; if ``2``, resolve ``*``, ``?`` and ``[]``.
+    recursive : bool, default=False
+        If ``True``, the pattern ``**`` will match any files and zero or more
+        directories, subdirectories and symbolic links to directories.
+    type : str, default='a'
+        The type of file. If ``a``, include all types; if ``d``, include
+        directories; if ``f``, include files.
+
+    Yields
+    ------
+    matched_pathname : str
+        The glob matched pathname.
+    """
+
+    generator = glob_scanner(pathname, mode=mode, recursive=recursive)
+    yield from _path_filter(generator, type=type)
+
+
+def glob_scanners(pathnames, *, mode=1, recursive=False):
     """Resolve a list of pathnames with glob patterns.
 
     Parameters
@@ -79,13 +127,13 @@ def glob_scanner(pathnames, *, mode=1, recursive=False):
         The glob matched pathname.
     """
 
-    glob_func = _get_glob_func(mode)
+    glob = _get_glob(mode)
     for pathname in pathnames:
-        yield from glob_func(pathname, recursive=recursive)
+        yield from glob(pathname, recursive=recursive)
 
 
-def glob_filter(pathnames, *, mode=1, recursive=False, type="a"):
-    """Resolve a list of pathnames with glob patterns.
+def glob_filters(pathnames, *, mode=1, recursive=False, type="a"):
+    """Resolve and filter a list of pathnames with glob patterns.
 
     Parameters
     ----------
@@ -107,21 +155,5 @@ def glob_filter(pathnames, *, mode=1, recursive=False, type="a"):
         The glob matched pathname.
     """
 
-    _check_str(type, "type")
-    type = type.lower()
-    if type not in {"a", "d", "f"}:
-        raise ValueError(f"type must be in {{'a', 'd', 'f'}}, got '{type}'")
-
-    all_ok = type == "a"
-    dir_ok = all_ok or type == "d"
-    file_ok = all_ok or type == "f"
-    for path in glob_scanner(pathnames, mode=mode, recursive=recursive):
-        if os.path.isdir(path):
-            if dir_ok:
-                yield path
-        elif os.path.isfile(path):
-            if file_ok:
-                yield path
-        else:
-            if all_ok:
-                yield path
+    generator = glob_scanners(pathnames, mode=mode, recursive=recursive)
+    yield from _path_filter(generator, type=type)
